@@ -8,10 +8,16 @@
 import sys
 import time
 import traceback
-import  os
 
 print_raw = print
-word_color_in_block = 30 if os.name == 'nt' else 37
+
+def stdout_write(msg:str):
+    sys.stdout.write(msg)
+    sys.stdout.flush()
+
+def stderr_write(msg:str):
+    sys.stderr.write(msg)
+    sys.stderr.flush()
 
 # noinspection PyProtectedMember,PyUnusedLocal,PyIncorrectDocstring
 def nb_print(*args, sep=' ', end='\n', file=None):
@@ -22,8 +28,7 @@ def nb_print(*args, sep=' ', end='\n', file=None):
     """
     args = (str(arg) for arg in args)  # REMIND 防止是数字不能被join
     if file == sys.stderr:
-        sys.stderr.write(sep.join(args))  # 如 threading 模块第926行，打印线程错误，希望保持原始的红色错误方式，不希望转成蓝色。
-
+        stderr_write(sep.join(args)) # 如 threading 模块第926行，打印线程错误，希望保持原始的红色错误方式，不希望转成蓝色。
     elif file in [sys.stdout, None]:
         # 获取被调用函数在被调用时所处代码行数
         line = sys._getframe().f_back.f_lineno
@@ -31,10 +36,10 @@ def nb_print(*args, sep=' ', end='\n', file=None):
         file_name = sys._getframe(1).f_code.co_filename
         # sys.stdout.write(f'"{__file__}:{sys._getframe().f_lineno}"    {x}\n')
         if True:
-            sys.stdout.write(
-                f'\033[0;34m{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   \033[0;{word_color_in_block};44m{sep.join(args)}\033[0m{end} \033[0m')  # 36  93 96 94
+            stdout_write(
+                f'\033[0;34m{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   \033[0;30;44m{sep.join(args)}\033[0m{end} \033[0m')  # 36  93 96 94
         else:
-            sys.stdout.write(
+            stdout_write(
                 f'\033[0;34m{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   {sep.join(args)} {end} \033[0m')  # 36  93 96 94
         # sys.stdout.write(f'\033[0;30;44m"{file_name}:{line}"  {time.strftime("%H:%M:%S")}  {"".join(args)}\033[0m\n')
     else:  # 例如traceback模块的print_exception函数 file的入参是   <_io.StringIO object at 0x00000264F2F065E8>，必须把内容重定向到这个对象里面，否则exception日志记录不了错误堆栈。
@@ -61,9 +66,10 @@ def print_exception(etype, value, tb, limit=None, file=None, chain=True):
             type(value), value, tb, limit=limit).format(chain=chain):
         # print(line, file=file, end="")
         if file != sys.stderr:
-            sys.stderr.write(f'{line} \n')
+            stderr_write(f'{line} \n')
         else:
-            sys.stdout.write(f'{line} \n')
+            stdout_write(f'{line} \n')
+
 
 
 # print = nb_print
@@ -98,11 +104,12 @@ def patch_print():
 
 
 def common_print(*args, sep=' ', end='\n', file=None):
-    args = (str(arg) for arg in args)  # REMIND 防止是数字或其他非字符串不能被join
+    args = (str(arg) for arg in args)
+    args = (str(arg) for arg in args)  # REMIND 防止是数字不能被join
     if file == sys.stderr:
-        sys.stderr.write(sep.join(args) + end)  # 如 threading 模块第926行，打印线程错误，希望保持原始的红色错误方式，不希望转成蓝色。
+        stderr_write(sep.join(args) + end) # 如 threading 模块第926行，打印线程错误，希望保持原始的红色错误方式，不希望转成蓝色。
     else:
-        sys.stdout.write(sep.join(args) + end)
+        stdout_write(sep.join(args) + end)
 
 
 def reverse_patch_print():
@@ -114,6 +121,7 @@ def reverse_patch_print():
     #     __builtins__.print = common_print
     # except AttributeError:
     #     __builtins__['print'] = common_print
+
     try:
         __builtins__.print = print_raw
     except AttributeError:
@@ -125,7 +133,6 @@ if __name__ == '__main__':
     patch_print()
     print(0)
     nb_print(123, 'abc')
-    print = nb_print
     print(456, 'def')
     print('http://www.baidu.com')
 
